@@ -78,7 +78,7 @@ fn run() -> Result<i32> {
         }
         let shell = get_shell_path().ok_or_else(|| anyhow!("Not found shell"))?;
         let (script_dir, script_file) =
-            get_script_path().ok_or_else(|| anyhow!("Not found {}", get_script_name()))?;
+            get_script_path().ok_or_else(|| anyhow!("Not found script file"))?;
         let mut command = process::Command::new(&shell);
         command.arg(&script_file);
         command.args(&script_args);
@@ -110,35 +110,57 @@ fn parse_script_args(args: &[String]) -> Result<(String, Vec<String>)> {
 }
 
 fn get_script_path() -> Option<(PathBuf, PathBuf)> {
-    let name = get_script_name();
+    let candicates = candicate_script_names();
     let mut dir = env::current_dir().ok()?;
     loop {
-        let path = dir.join(&name);
-        if path.exists() {
-            return Some((dir, path));
+        for name in candicates.iter() {
+            let path = dir.join(name);
+            if path.exists() {
+                return Some((dir, path));
+            }
         }
         dir = dir.parent()?.to_path_buf();
     }
 }
 
-fn get_script_name() -> String {
-    env::var("ARGC_SCRIPT").unwrap_or_else(|_| "argcfile".into())
+fn candicate_script_names() -> Vec<String> {
+    let mut names = vec![];
+    if let Ok(name) = env::var("ARGC_SCRIPT") {
+        names.push(name.clone());
+        if !name.ends_with(".sh") {
+            names.push(format!("{}.sh", name));
+        }
+    }
+    names.push("argcfile".into());
+    names.push("Argcfile".into());
+    names.push("argcfile.sh".into());
+    names.push("Argcfile.sh".into());
+    names
 }
 
 fn get_shell_path() -> Option<PathBuf> {
     let shell = match env::var("ARGC_SHELL") {
         Ok(v) => Path::new(&v).to_path_buf(),
-        Err(_) => {
-            if cfg!(windows) {
-                let git = which("git").ok()?;
-                git.parent()?.parent()?.join("bin").join("bash.exe")
-            } else {
-                which("bash").ok()?
-            }
-        }
+        Err(_) => get_bash_path()?,
     };
     if !shell.exists() {
         return None;
     }
     Some(shell)
 }
+
+#[cfg(windows)]
+fn get_bash_path() -> Option<PathBuf> {
+    if let Ok(bash) = which("bash") {
+        if bash.display().to_string().to_lowercase() != "c:\\windows\\system32\\bash.exe" {
+            return Some(bash);
+        }
+    }
+    let git = which("git").ok()?;
+    Some(git.parent()?.parent()?.join("bin").join("bash.exe"))
+}
+
+#[cfg(not(windows))]
+fn get_bash_path() -> Option<PathBuf> {
+    which("bash").ok()
+}
