@@ -1,5 +1,9 @@
+mod fixtures;
+
 #[macro_use]
 mod macros;
+mod argcfile;
+mod cli;
 mod complete_test;
 mod escape_test;
 mod fail_test;
